import os

def get_dmidata():
    p = os.popen("dmidecode")
    data = p.read()
    if p.close() > 1:
        return {}
    
    items = data.split("\n\n")
    items = items[1:]

    def parse_items(i):
        it = i.split("\n")
        it = it[2:]
        voices = {}
        for x in it:
            s = x.strip().split(":")
            if len(s) > 1:
                k = s[0].strip()
                v = s[1].strip()
            voices[k] = v
        return voices
    
    data = {"system": parse_items(items[1]),
            "board": parse_items(items[2]),
            "chassis": parse_items(items[3])}

    return data



dmi_interesting = [ ('chassis','Type',"chassis_type"),
                    ('system','Manufacturer', "system_vendor"),
                    ('system','Serial Number', "serial_serial"),
                    ('system','Product Name', "system_product")
                    ]

def get_data():
    client_data = {}

    dmidata = get_dmidata()    
    # collect data from DMI
    for k in dmi_interesting:
        if dmidata.has_key(k[0]):
            if dmidata[k[0]].has_key(k[1]):
                client_data[k[2]] = dmidata[k[0]][k[1]]

    # collect video size
    try:
        video_size = open('/var/tmp/fuss-display-size').read().strip()
        client_data['video_size'] = video_size
    except:
        pass


    # Dual boot
    try:
        f = open('/boot/grub/menu.lst')
        for x in f.readlines():
            if x.startswith("title"):
                if "windows" in x.lower():
                    client_data['dualboot'] = " ".join(x.split(" ")[1:])
                    break
    except:
        pass
    
        
    # N. of installed packages
    p = os.popen("dpkg -l | wc -l", "r")
    client_data['ninstalledpackages'] = int(p.read()) - 5

    # disk usage for every physical filesystems
    p = os.popen('df -h | grep -e "^/dev" |  tr -s " " | cut -d " " -f 6,5','r')
    data = p.readlines()
    for line in data:
        percentage,fs = line.split()
        client_data[fs] = percentage

    # fuss client version
    p = os.popen("dpkg -l | grep fuss-client | awk  '{print $3;}'",'r')
    data = p.read().strip()
    client_data['fussclient'] = data

    # disk size for every physical filesystems
    p = os.popen('df -h | grep -e "^/dev" |  tr -s " " | cut -d " " -f 1,2','r')
    data = p.readlines()
    for line in data:
        percentage, device = line.split()
        client_data[device] = percentage

    # usb devices
    p = os.popen("lsusb",'r')
    data = p.readlines()
    for line in data:
        dev = line.strip().split("ID")[1][1:]
        if dev[:9] != "0000:0000":
            id = "usb:"+dev[:9]
            desc = dev[10:]
            client_data[id] = desc
            
    # total amount of ram memory
    p = os.popen("free -m | head -2 | tail -1 | awk  '{print $2;}'",'r')
    data = p.read().strip()
    client_data['totalram'] = data

    # video card
    p = os.popen("lspci | grep VGA",'r')
    data = p.read().strip()
    client_data['videocard'] = data[35:]
    
    # cpu type
    p = os.popen("grep 'model name' /proc/cpuinfo | uniq",'r')
    data = p.read().strip()
    client_data['cputype'] = data
    
    # cpu speed
    p = os.popen("grep 'cpu MHz' /proc/cpuinfo | uniq",'r')
    data = p.read().strip()
    client_data['cpuspeed'] = data

    return client_data
